Test Report

# Summary

Started | 2025-06-02 15:22:30
Ended | 2025-06-02 15:31:31
Duration | 0:09:01.662075
Total run time | 0:08:43.990901

100 passed 5 skipped

# Warnings

## Warnings 190

- DeprecationWarning Please import `gaussian_filter1d` from the `scipy.ndimage` namespace; the `scipy.ndimage.filters` namespace is deprecated and will be removed in SciPy 2.0.0.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/isofit/utils/instrument_model.py:25
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=171) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.730812

### PASSED Test_CLIParser::test_json_opts 0:00:00.190989

Started | 2025-06-02 15:22:43
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.190989
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.120049

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.120049
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.080730

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.080730
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.128573

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.128573
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046473

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.046473
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.081320

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.081320
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.082679

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.082679
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.355137

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.008793

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.008793
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.017820

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.017820
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.036098

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.036098
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043801

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.043801
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.033239

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.033239
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.033142

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.033142
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.016053

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.016053
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.015861

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.015861
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.024578

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.024578
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.015867

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.015867
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.033061

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.033061
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.042818

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.042818
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.034006

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:44
Duration | 0:00:00.034006
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:04.180480

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.487882

Started | 2025-06-02 15:22:44
Ended | 2025-06-02 15:22:53
Duration | 0:00:08.487882
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpel1z269z'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 15:22:45:   Reading metadata for VNIR detector...
    2025/06/02 15:22:45:   Calculating solar irradiance...
    2025/06/02 15:22:45:   Reading metadata for SWIR detector...
    2025/06/02 15:22:46:   Calculating solar irradiance...
    2025/06/02 15:22:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:22:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:22:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:22:46:   Reading metadata for VNIR detector...
    2025/06/02 15:22:46:   Calculating solar irradiance...
    2025/06/02 15:22:46:   Reading metadata for SWIR detector...
    2025/06/02 15:22:46:   Calculating solar irradiance...
    2025/06/02 15:22:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:22:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:22:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:22:47:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:22:47:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:22:47:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:22:47:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:22:47:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:22:48:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:22:48:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/06/02 15:22:48:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 15:22:48:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/06/02 15:22:48:   Starting orthorectification...
    2025/06/02 15:22:48:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/06/02 15:22:48:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:22:49:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:22:51:   Merging VNIR and SWIR data...
    2025/06/02 15:22:51:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:22:51:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:22:51:   Generating L2A metadata...
    2025/06/02 15:22:53:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:22:53:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/06/02 15:22:53:   L2A product successfully written!
    2025/06/02 15:22:53:   Total runtime of the processing chain: 0:00:08.424576

##### Captured stderr call

    2025/06/02 15:22:47:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:22:47:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:22:47:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:22:47:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:22:47:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:22:53:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 15:22:53:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:22:53:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:57.125344

Started | 2025-06-02 15:22:53
Ended | 2025-06-02 15:23:50
Duration | 0:00:57.125344
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmptua6g7r3'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 15:22:53:   Reading metadata for VNIR detector...
    2025/06/02 15:22:54:   Calculating solar irradiance...
    2025/06/02 15:22:54:   Reading metadata for SWIR detector...
    2025/06/02 15:22:54:   Calculating solar irradiance...
    2025/06/02 15:22:54:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:22:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:22:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:22:55:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:22:55:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:22:55:   Computing VNIR geolayer...
    2025/06/02 15:22:56:   Computing SWIR geolayer...
    2025/06/02 15:22:56:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 15:22:56:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 15:22:57:   Preparing reference image for co-registration.
    2025/06/02 15:22:57:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 15:23:08:   Generating misregistration array.
    interpolation runtime: 0.18s
    interpolation runtime: 0.16s
    2025/06/02 15:23:08:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 15:23:08:   Applying results of spatial optimization to geolayer.
    2025/06/02 15:23:09:   Pre-processing DEM for VNIR...
    2025/06/02 15:23:09:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 15:23:09:   Pre-processing DEM for SWIR...
    2025/06/02 15:23:09:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 15:23:09:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 15:23:10:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 15:23:10:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 15:23:10:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 15:23:10:   Setting up forward operator...
    2025/06/02 15:23:10:   SICOR is applied to land AND water pixels.
    2025/06/02 15:23:10:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 15:23:11:   Getting observation metadata...
    2025/06/02 15:23:11:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 15:23:11:   Loading solar irradiance model...
    2025/06/02 15:23:11:   Loading RT LUT...
    2025/06/02 15:23:11:   LUT file was properly downloaded and is available for AC!
    2025/06/02 15:23:11:   Converting LUT to Fontenla solar model...
    2025/06/02 15:23:12:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 15:23:33:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 15:23:33:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 15:23:33:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 15:23:35:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 15:23:35:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 15:23:35:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 15:23:35:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 15:23:35:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 15:23:36:   Preparing segmented SWIR L1B data cube...
    2025/06/02 15:23:36:   Performing 3 phases of water retrieval...
    2025/06/02 15:23:36:   Setting up multiprocessing...
    2025/06/02 15:23:36:   Multiprocessing on 24 cpu's
    2025/06/02 15:23:36:   Preparing optimal estimation input...
    2025/06/02 15:23:36:   Optimization...
    2025/06/02 15:23:38:   Done!
    2025/06/02 15:23:38:   Runtime: 2.18 s
    2025/06/02 15:23:38:   Smoothing segmented CWV retrieval map...
    2025/06/02 15:23:39:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 15:23:39:   Starting surface reflectance retrieval...
    2025/06/02 15:23:39:   Calculating surface reflectance for vnir detector...
    2025/06/02 15:23:41:   Calculating surface reflectance for swir detector...
    2025/06/02 15:23:44:   Smoothing segmented liquid water and ice maps...
    2025/06/02 15:23:45:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 15:23:45:   Joining results of atmospheric correction.
    2025/06/02 15:23:45:   Starting orthorectification...
    2025/06/02 15:23:45:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/06/02 15:23:45:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:23:46:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:23:47:   Merging VNIR and SWIR data...
    2025/06/02 15:23:47:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:23:47:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:23:47:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:23:47:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:23:48:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:23:48:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:23:48:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:23:48:   Generating L2A metadata...
    2025/06/02 15:23:49:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 15:23:50:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 15:23:50:   L2A product successfully written!
    2025/06/02 15:23:50:   Total runtime of the processing chain: 0:00:57.055267

##### Captured stderr call

    2025/06/02 15:22:53:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 15:22:56:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.4% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.3% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.6% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.8% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.2% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.4% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.8% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.4% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.4% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.6% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.3% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.5% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.6% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.7% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.6% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.4% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.3% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.2% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:10
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:10
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:10
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:10
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:10
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:10
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:10
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:10
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:10
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:10
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:10
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:10
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:10
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:10
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:10
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:10
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:10
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:10
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:10
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:10
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:10
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.0% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.3% Complete  => 0:00:00
    	progress: |======--------------------------------------------| 12.9% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 22.2% Complete  => 0:00:00
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:00
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:01
    	progress: |===================================---------------| 70.2% Complete  => 0:00:01
    	progress: |==========================================--------| 84.9% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 15:23:44:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:23:45:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:23:50:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 15:23:50:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:23:50:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:23:50:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.040365

Started | 2025-06-02 15:23:50
Ended | 2025-06-02 15:23:50
Duration | 0:00:00.040365
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:20.703849

Started | 2025-06-02 15:23:50
Ended | 2025-06-02 15:25:11
Duration | 0:01:20.703849
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmppe5j7x6m'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 15:23:50:   Reading metadata for VNIR detector...
    2025/06/02 15:23:51:   Calculating solar irradiance...
    2025/06/02 15:23:51:   Reading metadata for SWIR detector...
    2025/06/02 15:23:51:   Calculating solar irradiance...
    2025/06/02 15:23:51:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:23:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:23:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:23:51:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:23:51:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:23:52:   Computing VNIR geolayer...
    2025/06/02 15:23:52:   Computing SWIR geolayer...
    2025/06/02 15:23:52:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:23:52:   Percentage of defective pixels: 0.49
    2025/06/02 15:23:52:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 15:23:52:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:23:52:   Percentage of defective pixels: 0.50
    2025/06/02 15:23:52:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 15:23:52:   Pre-processing DEM for VNIR...
    2025/06/02 15:23:52:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 15:23:52:   Pre-processing DEM for SWIR...
    2025/06/02 15:23:52:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 15:23:52:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 15:23:53:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 15:23:53:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 15:23:53:   Setting up forward operator...
    2025/06/02 15:23:53:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/06/02 15:23:53:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 15:23:54:   Getting observation metadata...
    2025/06/02 15:23:54:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 15:23:54:   Loading solar irradiance model...
    2025/06/02 15:23:54:   Loading RT LUT...
    2025/06/02 15:23:54:   LUT file was properly downloaded and is available for AC!
    2025/06/02 15:23:54:   Converting LUT to Fontenla solar model...
    2025/06/02 15:23:54:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 15:24:14:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 15:24:15:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 15:24:15:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 15:24:16:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 15:24:16:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 15:24:16:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 15:24:16:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 15:24:16:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 15:24:16:   Preparing segmented SWIR L1B data cube...
    2025/06/02 15:24:16:   Performing 3 phases of water retrieval...
    2025/06/02 15:24:16:   Setting up multiprocessing...
    2025/06/02 15:24:16:   Multiprocessing on 16 cpu's
    2025/06/02 15:24:16:   Preparing optimal estimation input...
    2025/06/02 15:24:16:   Optimization...
    2025/06/02 15:24:18:   Done!
    2025/06/02 15:24:18:   Runtime: 1.40 s
    2025/06/02 15:24:18:   Smoothing segmented CWV retrieval map...
    2025/06/02 15:24:18:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 15:24:18:   Starting surface reflectance retrieval...
    2025/06/02 15:24:18:   Calculating surface reflectance for vnir detector...
    2025/06/02 15:24:20:   Calculating surface reflectance for swir detector...
    2025/06/02 15:24:21:   Smoothing segmented liquid water and ice maps...
    2025/06/02 15:24:21:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/06/02 15:24:21:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/06/02 15:24:21:   Landmask is EnMAP L1B
    Starting processing at 2025-06-02 15:24:22.081255
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:44.598582
    2025/06/02 15:25:06:   Joining results of atmospheric correction.
    2025/06/02 15:25:06:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 15:25:06:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:06:   Percentage of defective pixels: 0.49
    2025/06/02 15:25:06:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 15:25:06:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:07:   Percentage of defective pixels: 0.50
    2025/06/02 15:25:07:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 15:25:07:   Starting orthorectification...
    2025/06/02 15:25:07:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 15:25:07:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:25:07:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:25:08:   Merging VNIR and SWIR data...
    2025/06/02 15:25:08:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:25:08:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:25:08:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:25:08:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:25:08:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:25:08:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:25:09:   Orthorectifying 'polymer_logchl' attribute...
    2025/06/02 15:25:09:   Orthorectifying 'polymer_logfb' attribute...
    2025/06/02 15:25:09:   Orthorectifying 'polymer_rgli' attribute...
    2025/06/02 15:25:09:   Orthorectifying 'polymer_rnir' attribute...
    2025/06/02 15:25:09:   Orthorectifying 'polymer_bitmask' attribute...
    2025/06/02 15:25:09:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:25:10:   Generating L2A metadata...
    2025/06/02 15:25:10:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/06/02 15:25:11:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 15:25:11:   L2A product successfully written!
    2025/06/02 15:25:11:   Total runtime of the processing chain: 0:01:20.631922

##### Captured stderr call

    2025/06/02 15:23:50:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 2.4% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 7.3% Complete  => 0:00:00
    	progress: |=========-----------------------------------------| 17.1% Complete  => 0:00:00
    	progress: |=============-------------------------------------| 26.8% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/06/02 15:24:21:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:24:21:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:25:11:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 15:25:11:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:11:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:11:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:37.823039

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-06-02 15:25:11
Ended | 2025-06-02 15:25:49
Duration | 0:00:37.823039
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpkcqcslg2'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 15:25:11:   Reading metadata for VNIR detector...
    2025/06/02 15:25:11:   Calculating solar irradiance...
    2025/06/02 15:25:11:   Reading metadata for SWIR detector...
    2025/06/02 15:25:12:   Calculating solar irradiance...
    2025/06/02 15:25:12:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:25:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:25:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:25:12:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:25:12:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:25:12:   Computing VNIR geolayer...
    2025/06/02 15:25:12:   Computing SWIR geolayer...
    2025/06/02 15:25:13:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:13:   Percentage of defective pixels: 0.49
    2025/06/02 15:25:13:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 15:25:13:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:13:   Percentage of defective pixels: 0.50
    2025/06/02 15:25:13:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 15:25:13:   Pre-processing DEM for VNIR...
    2025/06/02 15:25:13:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 15:25:13:   Pre-processing DEM for SWIR...
    2025/06/02 15:25:13:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 15:25:13:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 15:25:13:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 15:25:13:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 15:25:13:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 15:25:13:   Setting up forward operator...
    2025/06/02 15:25:13:   SICOR is applied to land AND water pixels.
    2025/06/02 15:25:13:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 15:25:14:   Getting observation metadata...
    2025/06/02 15:25:14:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 15:25:14:   Loading solar irradiance model...
    2025/06/02 15:25:14:   Loading RT LUT...
    2025/06/02 15:25:14:   LUT file was properly downloaded and is available for AC!
    2025/06/02 15:25:14:   Converting LUT to Fontenla solar model...
    2025/06/02 15:25:15:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 15:25:37:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 15:25:37:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 15:25:37:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 15:25:39:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 15:25:39:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 15:25:39:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 15:25:39:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 15:25:39:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 15:25:39:   Preparing segmented SWIR L1B data cube...
    2025/06/02 15:25:39:   Performing 3 phases of water retrieval...
    2025/06/02 15:25:39:   Setting up multiprocessing...
    2025/06/02 15:25:39:   Multiprocessing on 16 cpu's
    2025/06/02 15:25:39:   Preparing optimal estimation input...
    2025/06/02 15:25:39:   Optimization...
    2025/06/02 15:25:41:   Done!
    2025/06/02 15:25:41:   Runtime: 2.03 s
    2025/06/02 15:25:41:   Smoothing segmented CWV retrieval map...
    2025/06/02 15:25:41:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 15:25:42:   Starting surface reflectance retrieval...
    2025/06/02 15:25:42:   Calculating surface reflectance for vnir detector...
    2025/06/02 15:25:43:   Calculating surface reflectance for swir detector...
    2025/06/02 15:25:45:   Smoothing segmented liquid water and ice maps...
    2025/06/02 15:25:45:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 15:25:45:   Joining results of atmospheric correction.
    2025/06/02 15:25:45:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 15:25:45:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:45:   Percentage of defective pixels: 0.49
    2025/06/02 15:25:45:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 15:25:45:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 15:25:45:   Percentage of defective pixels: 0.50
    2025/06/02 15:25:45:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 15:25:45:   Starting orthorectification...
    2025/06/02 15:25:45:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 15:25:45:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:25:46:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:25:46:   Merging VNIR and SWIR data...
    2025/06/02 15:25:46:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:25:47:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:25:47:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:25:47:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:25:47:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:25:47:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:25:47:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:25:48:   Generating L2A metadata...
    2025/06/02 15:25:48:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 15:25:49:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 15:25:49:   L2A product successfully written!
    2025/06/02 15:25:49:   Total runtime of the processing chain: 0:00:37.773252

##### Captured stderr call

    2025/06/02 15:25:11:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 15:25:13:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 4.2% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.4% Complete  => 0:00:00
    	progress: |======--------------------------------------------| 12.7% Complete  => 0:00:00
    	progress: |========------------------------------------------| 16.9% Complete  => 0:00:00
    	progress: |============--------------------------------------| 24.1% Complete  => 0:00:00
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:00
    	progress: |============================----------------------| 56.0% Complete  => 0:00:00
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:01
    	progress: |=====================================-------------| 74.1% Complete  => 0:00:01
    	progress: |==============================================----| 92.2% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 15:25:45:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:25:45:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 15:25:49:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 15:25:49:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 15:25:49:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:08.025039

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.827430

Started | 2025-06-02 15:25:49
Ended | 2025-06-02 15:25:53
Duration | 0:00:03.827430
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.100790

Started | 2025-06-02 15:25:53
Ended | 2025-06-02 15:25:53
Duration | 0:00:00.100790
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:03.853093

Started | 2025-06-02 15:25:53
Ended | 2025-06-02 15:25:56
Duration | 0:00:03.853093
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.170465

Started | 2025-06-02 15:25:56
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.170465
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003086

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.003086
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002728

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.002728
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001300

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.001300
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.001918

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.001918
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002778

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.002778
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003469

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.003469
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.046167

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.046167
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001098

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.001098
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001267

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.001267
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.004425

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.004425
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.005024

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.005024
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.404103

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.063194

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.063194
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.025439

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.025439
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.027169

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.027169
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.035771

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.035771
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.033672

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.033672
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.024144

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.024144
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.022532

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.022532
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.172183

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:57
Duration | 0:00:00.172183
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:22.793016

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.295431

Started | 2025-06-02 15:25:57
Ended | 2025-06-02 15:25:59
Duration | 0:00:02.295431
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 15:25:58:   Reading metadata for VNIR detector...
    2025/06/02 15:25:58:   Calculating solar irradiance...
    2025/06/02 15:25:58:   Reading metadata for SWIR detector...
    2025/06/02 15:25:58:   Calculating solar irradiance...
    2025/06/02 15:25:58:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:25:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:25:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:25:59:   Computing VNIR geolayer...
    2025/06/02 15:25:59:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 15:25:57:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/06/02 15:25:59:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/06/02 15:25:59:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.006968

Started | 2025-06-02 15:25:59
Ended | 2025-06-02 15:25:59
Duration | 0:00:00.006968
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:25:59:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010172

Started | 2025-06-02 15:25:59
Ended | 2025-06-02 15:25:59
Duration | 0:00:00.010172
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.905729

Started | 2025-06-02 15:25:59
Ended | 2025-06-02 15:26:01
Duration | 0:00:01.905729
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001163

Started | 2025-06-02 15:26:01
Ended | 2025-06-02 15:26:01
Duration | 0:00:00.001163
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:18.573553

Started | 2025-06-02 15:26:01
Ended | 2025-06-02 15:26:20
Duration | 0:00:18.573553
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:01:57.259062

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:09.131139

Started | 2025-06-02 15:26:20
Ended | 2025-06-02 15:26:29
Duration | 0:00:09.131139
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:26:20:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 15:26:20:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 15:26:20:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 15:26:20:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.2
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release main/v1.2.7
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.476458

Started | 2025-06-02 15:26:29
Ended | 2025-06-02 15:26:30
Duration | 0:00:00.476458
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:26:29:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 15:26:29:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 15:26:30:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 15:26:30:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.001239

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 15:26:30
Ended | 2025-06-02 15:26:30
Duration | 0:00:00.001239
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:13.066501

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 15:26:30
Ended | 2025-06-02 15:27:43
Duration | 0:01:13.066501
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:26:30:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 15:26:30:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 15:26:30:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 15:26:30:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 15:26:30:   Generating LUT file...
    2025/06/02 15:26:41:   Flightline ID: 20220717T110603Z
    2025/06/02 15:26:41:   no noise path found, proceeding without
    2025/06/02 15:26:41:   Running ISOFIT...
    2025/06/02 15:26:41:   Loading config file: /tmp/tmpb5_yka8x/workdir/config/isofit_config.json
    2025/06/02 15:26:41:   Checking config sections for configuration issues
    2025/06/02 15:26:41:   Configuration file checks complete, no errors found.
    2025/06/02 15:26:50:   Building first forward model, will generate any necessary LUTs
    2025/06/02 15:26:50:   Loading from wavelength_file: /tmp/tmpb5_yka8x/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/06/02 15:26:50:   Prebuilt LUT provided
    2025/06/02 15:26:57:   Loading LUT into memory
    2025/06/02 15:26:58:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/06/02 15:27:16:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/06/02 15:27:40:   Inversions complete.  23.73s total, 4.2138 spectra/s, 0.2107 spectra/s/core
    2025/06/02 15:27:40:   ISOFIT finished.
    2025/06/02 15:27:40:   Stopping ray.

##### Captured stderr call

    2025/06/02 15:26:41:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-06-02 15:26:46,007	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-06-02 15:26:47,219	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1748878061.325114     864 chttp2_transport.cc:1182] ipv4:172.17.0.14:62540: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {grpc_status:14, http2_error:2, created_time:"2025-06-02T15:27:41.32510366+00:00"}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000590

Started | 2025-06-02 15:27:43
Ended | 2025-06-02 15:27:43
Duration | 0:00:00.000590
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000458

Started | 2025-06-02 15:27:43
Ended | 2025-06-02 15:27:43
Duration | 0:00:00.000458
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.427742

Started | 2025-06-02 15:27:43
Ended | 2025-06-02 15:27:45
Duration | 0:00:02.427742
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:27:43:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/06/02 15:27:45:   LUT zipfile successfully downloaded.
    2025/06/02 15:27:45:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 15:27:45:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:21.344554

Started | 2025-06-02 15:27:45
Ended | 2025-06-02 15:28:06
Duration | 0:00:21.344554
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:27:45:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 15:27:45:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 15:27:45:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 15:27:45:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 15:27:46:   Reading Input Data
    2025/06/02 15:27:46:   Reading metadata for VNIR detector...
    2025/06/02 15:27:46:   Calculating solar irradiance...
    2025/06/02 15:27:46:   Reading metadata for SWIR detector...
    2025/06/02 15:27:46:   Calculating solar irradiance...
    2025/06/02 15:27:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:27:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:27:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:27:47:   Computing VNIR geolayer...
    2025/06/02 15:27:47:   Computing SWIR geolayer...
    2025/06/02 15:27:47:   Starting orthorectification...
    2025/06/02 15:27:47:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 15:27:47:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:27:48:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:27:49:   Merging VNIR and SWIR data...
    2025/06/02 15:27:50:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:27:50:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:27:50:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:27:50:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:27:50:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:27:51:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:27:51:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:27:52:   Generating L2A metadata...
    2025/06/02 15:27:52:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpbwgv7mym/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/06/02 15:27:53:   Generating location file...
    2025/06/02 15:27:53:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpbwgv7mym/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/06/02 15:27:54:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpbwgv7mym/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/06/02 15:27:54:   Generating wavelength file...
    2025/06/02 15:27:54:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/06/02 15:27:56:   Generating LUT file...

##### Captured stderr call

    2025/06/02 15:27:46:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.0% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.0% Complete  => 0:00:00
    Warping progress     |================================================--| 96.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.1% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000547

Started | 2025-06-02 15:28:06
Ended | 2025-06-02 15:28:06
Duration | 0:00:00.000547
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000642

Started | 2025-06-02 15:28:06
Ended | 2025-06-02 15:28:06
Duration | 0:00:00.000642
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:10.809190

Started | 2025-06-02 15:28:06
Ended | 2025-06-02 15:28:17
Duration | 0:00:10.809190
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stderr call

    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

## tests/test_l1b_reader.py 10 0:01:49.249769

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:18.100433

Started | 2025-06-02 15:28:17
Ended | 2025-06-02 15:28:35
Duration | 0:00:18.100433
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:28:18:   Reading Input Data
    2025/06/02 15:28:18:   Reading metadata for VNIR detector...
    2025/06/02 15:28:18:   Calculating solar irradiance...
    2025/06/02 15:28:18:   Reading metadata for SWIR detector...
    2025/06/02 15:28:18:   Calculating solar irradiance...
    2025/06/02 15:28:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:19:   Reading metadata for VNIR detector...
    2025/06/02 15:28:19:   Calculating solar irradiance...
    2025/06/02 15:28:19:   Reading metadata for SWIR detector...
    2025/06/02 15:28:19:   Calculating solar irradiance...
    2025/06/02 15:28:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:20:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:20:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:20:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:20:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:20:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5i4squzg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:20:   L1B product successfully written!
    2025/06/02 15:28:20:   Reading Input Data
    2025/06/02 15:28:20:   Reading metadata for VNIR detector...
    2025/06/02 15:28:20:   Calculating solar irradiance...
    2025/06/02 15:28:20:   Reading metadata for SWIR detector...
    2025/06/02 15:28:21:   Calculating solar irradiance...
    2025/06/02 15:28:21:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:21:   Reading Input Data
    2025/06/02 15:28:21:   Reading metadata for VNIR detector...
    2025/06/02 15:28:21:   Calculating solar irradiance...
    2025/06/02 15:28:21:   Reading metadata for SWIR detector...
    2025/06/02 15:28:21:   Calculating solar irradiance...
    2025/06/02 15:28:21:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:22:   Reading metadata for VNIR detector...
    2025/06/02 15:28:22:   Calculating solar irradiance...
    2025/06/02 15:28:22:   Reading metadata for SWIR detector...
    2025/06/02 15:28:22:   Calculating solar irradiance...
    2025/06/02 15:28:22:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:22:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:22:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:22:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:22:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:22:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:24:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:24:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5hvwae3b/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:25:   L1B product successfully written!
    2025/06/02 15:28:25:   Reading Input Data
    2025/06/02 15:28:25:   Reading metadata for VNIR detector...
    2025/06/02 15:28:25:   Calculating solar irradiance...
    2025/06/02 15:28:25:   Reading metadata for SWIR detector...
    2025/06/02 15:28:25:   Calculating solar irradiance...
    2025/06/02 15:28:25:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:25:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:27:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:27:   Reading Input Data
    2025/06/02 15:28:27:   Reading metadata for VNIR detector...
    2025/06/02 15:28:27:   Calculating solar irradiance...
    2025/06/02 15:28:27:   Reading metadata for SWIR detector...
    2025/06/02 15:28:28:   Calculating solar irradiance...
    2025/06/02 15:28:28:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:28:   Reading metadata for VNIR detector...
    2025/06/02 15:28:28:   Calculating solar irradiance...
    2025/06/02 15:28:28:   Reading metadata for SWIR detector...
    2025/06/02 15:28:28:   Calculating solar irradiance...
    2025/06/02 15:28:28:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:29:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:29:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:29:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpgg13cimh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:28:29:   L1B product successfully written!
    2025/06/02 15:28:29:   Reading Input Data
    2025/06/02 15:28:29:   Reading metadata for VNIR detector...
    2025/06/02 15:28:29:   Calculating solar irradiance...
    2025/06/02 15:28:30:   Reading metadata for SWIR detector...
    2025/06/02 15:28:30:   Calculating solar irradiance...
    2025/06/02 15:28:30:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:30:   Reading Input Data
    2025/06/02 15:28:30:   Reading metadata for VNIR detector...
    2025/06/02 15:28:30:   Calculating solar irradiance...
    2025/06/02 15:28:30:   Reading metadata for SWIR detector...
    2025/06/02 15:28:31:   Calculating solar irradiance...
    2025/06/02 15:28:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:31:   Reading metadata for VNIR detector...
    2025/06/02 15:28:32:   Calculating solar irradiance...
    2025/06/02 15:28:32:   Reading metadata for SWIR detector...
    2025/06/02 15:28:32:   Calculating solar irradiance...
    2025/06/02 15:28:32:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:33:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:33:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:33:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:33:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:33:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmplnaorxn1/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:28:34:   L1B product successfully written!
    2025/06/02 15:28:34:   Reading Input Data
    2025/06/02 15:28:34:   Reading metadata for VNIR detector...
    2025/06/02 15:28:34:   Calculating solar irradiance...
    2025/06/02 15:28:34:   Reading metadata for SWIR detector...
    2025/06/02 15:28:34:   Calculating solar irradiance...
    2025/06/02 15:28:34:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:34:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:35:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:28:20:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:20:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:22:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:22:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:22:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:22:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:22:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:24:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:24:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:24:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:24:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:24:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:29:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:29:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:29:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:29:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:33:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:34:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:34:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:34:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:34:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:34:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.272040

Started | 2025-06-02 15:28:35
Ended | 2025-06-02 15:28:51
Duration | 0:00:15.272040
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:28:36:   Reading Input Data
    2025/06/02 15:28:36:   Reading metadata for VNIR detector...
    2025/06/02 15:28:36:   Calculating solar irradiance...
    2025/06/02 15:28:36:   Reading metadata for SWIR detector...
    2025/06/02 15:28:37:   Calculating solar irradiance...
    2025/06/02 15:28:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:37:   Reading metadata for VNIR detector...
    2025/06/02 15:28:37:   Calculating solar irradiance...
    2025/06/02 15:28:37:   Reading metadata for SWIR detector...
    2025/06/02 15:28:37:   Calculating solar irradiance...
    2025/06/02 15:28:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:38:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:38:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:38:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:38:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:38:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpduzmvnts/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:38:   L1B product successfully written!
    2025/06/02 15:28:38:   Reading Input Data
    2025/06/02 15:28:38:   Reading metadata for VNIR detector...
    2025/06/02 15:28:38:   Calculating solar irradiance...
    2025/06/02 15:28:38:   Reading metadata for SWIR detector...
    2025/06/02 15:28:39:   Calculating solar irradiance...
    2025/06/02 15:28:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:39:   Reading Input Data
    2025/06/02 15:28:39:   Reading metadata for VNIR detector...
    2025/06/02 15:28:39:   Calculating solar irradiance...
    2025/06/02 15:28:39:   Reading metadata for SWIR detector...
    2025/06/02 15:28:39:   Calculating solar irradiance...
    2025/06/02 15:28:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:39:   Reading metadata for VNIR detector...
    2025/06/02 15:28:40:   Calculating solar irradiance...
    2025/06/02 15:28:40:   Reading metadata for SWIR detector...
    2025/06/02 15:28:40:   Calculating solar irradiance...
    2025/06/02 15:28:40:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:40:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:40:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:40:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:40:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:40:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:41:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp8ozmo1ep/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:42:   L1B product successfully written!
    2025/06/02 15:28:42:   Reading Input Data
    2025/06/02 15:28:42:   Reading metadata for VNIR detector...
    2025/06/02 15:28:42:   Calculating solar irradiance...
    2025/06/02 15:28:42:   Reading metadata for SWIR detector...
    2025/06/02 15:28:42:   Calculating solar irradiance...
    2025/06/02 15:28:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:42:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:44:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:44:   Reading Input Data
    2025/06/02 15:28:44:   Reading metadata for VNIR detector...
    2025/06/02 15:28:44:   Calculating solar irradiance...
    2025/06/02 15:28:44:   Reading metadata for SWIR detector...
    2025/06/02 15:28:45:   Calculating solar irradiance...
    2025/06/02 15:28:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:45:   Reading metadata for VNIR detector...
    2025/06/02 15:28:45:   Calculating solar irradiance...
    2025/06/02 15:28:45:   Reading metadata for SWIR detector...
    2025/06/02 15:28:45:   Calculating solar irradiance...
    2025/06/02 15:28:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:46:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:46:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:46:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnbg1kwgx/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:28:46:   L1B product successfully written!
    2025/06/02 15:28:46:   Reading Input Data
    2025/06/02 15:28:46:   Reading metadata for VNIR detector...
    2025/06/02 15:28:46:   Calculating solar irradiance...
    2025/06/02 15:28:46:   Reading metadata for SWIR detector...
    2025/06/02 15:28:46:   Calculating solar irradiance...
    2025/06/02 15:28:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:46:   Reading Input Data
    2025/06/02 15:28:47:   Reading metadata for VNIR detector...
    2025/06/02 15:28:47:   Calculating solar irradiance...
    2025/06/02 15:28:47:   Reading metadata for SWIR detector...
    2025/06/02 15:28:47:   Calculating solar irradiance...
    2025/06/02 15:28:47:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:47:   Reading metadata for VNIR detector...
    2025/06/02 15:28:47:   Calculating solar irradiance...
    2025/06/02 15:28:47:   Reading metadata for SWIR detector...
    2025/06/02 15:28:48:   Calculating solar irradiance...
    2025/06/02 15:28:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:48:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:48:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:28:48:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:49:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:49:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptffg_ea3/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:28:49:   L1B product successfully written!
    2025/06/02 15:28:49:   Reading Input Data
    2025/06/02 15:28:49:   Reading metadata for VNIR detector...
    2025/06/02 15:28:49:   Calculating solar irradiance...
    2025/06/02 15:28:49:   Reading metadata for SWIR detector...
    2025/06/02 15:28:50:   Calculating solar irradiance...
    2025/06/02 15:28:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:50:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:50:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:28:38:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 15:28:38:   Set the number of line to 50
    2025/06/02 15:28:38:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:38:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 15:28:38:   Set the number of line to 50
    2025/06/02 15:28:38:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:38:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:40:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 15:28:40:   Set the number of line to 50
    2025/06/02 15:28:40:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:40:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:40:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:40:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:40:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:40:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 15:28:40:   Set the number of line to 50
    2025/06/02 15:28:42:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:42:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:42:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:42:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:42:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:46:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:46:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:46:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:46:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:46:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:48:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:48:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:28:49:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:49:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:49:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:49:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:49:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:16.498353

Started | 2025-06-02 15:28:51
Ended | 2025-06-02 15:29:07
Duration | 0:00:16.498353
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:28:51:   Reading Input Data
    2025/06/02 15:28:51:   Reading metadata for VNIR detector...
    2025/06/02 15:28:52:   Calculating solar irradiance...
    2025/06/02 15:28:52:   Reading metadata for SWIR detector...
    2025/06/02 15:28:52:   Calculating solar irradiance...
    2025/06/02 15:28:52:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:52:   Reading metadata for VNIR detector...
    2025/06/02 15:28:52:   Calculating solar irradiance...
    2025/06/02 15:28:52:   Reading metadata for SWIR detector...
    2025/06/02 15:28:53:   Calculating solar irradiance...
    2025/06/02 15:28:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:53:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:53:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:53:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:53:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:53:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpx436rkt3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:53:   L1B product successfully written!
    2025/06/02 15:28:53:   Reading Input Data
    2025/06/02 15:28:53:   Reading metadata for VNIR detector...
    2025/06/02 15:28:54:   Calculating solar irradiance...
    2025/06/02 15:28:54:   Reading metadata for SWIR detector...
    2025/06/02 15:28:54:   Calculating solar irradiance...
    2025/06/02 15:28:54:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:54:   Reading Input Data
    2025/06/02 15:28:54:   Reading metadata for VNIR detector...
    2025/06/02 15:28:54:   Calculating solar irradiance...
    2025/06/02 15:28:54:   Reading metadata for SWIR detector...
    2025/06/02 15:28:55:   Calculating solar irradiance...
    2025/06/02 15:28:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:55:   Reading metadata for VNIR detector...
    2025/06/02 15:28:55:   Calculating solar irradiance...
    2025/06/02 15:28:55:   Reading metadata for SWIR detector...
    2025/06/02 15:28:55:   Calculating solar irradiance...
    2025/06/02 15:28:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:28:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:28:56:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:56:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:56:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:56:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:28:56:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:28:57:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:28:57:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp9fufw5lz/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:28:58:   L1B product successfully written!
    2025/06/02 15:28:58:   Reading Input Data
    2025/06/02 15:28:58:   Reading metadata for VNIR detector...
    2025/06/02 15:28:58:   Calculating solar irradiance...
    2025/06/02 15:28:58:   Reading metadata for SWIR detector...
    2025/06/02 15:28:58:   Calculating solar irradiance...
    2025/06/02 15:28:58:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:28:58:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:00:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:00:   Reading Input Data
    2025/06/02 15:29:00:   Reading metadata for VNIR detector...
    2025/06/02 15:29:01:   Calculating solar irradiance...
    2025/06/02 15:29:01:   Reading metadata for SWIR detector...
    2025/06/02 15:29:01:   Calculating solar irradiance...
    2025/06/02 15:29:01:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:01:   Reading metadata for VNIR detector...
    2025/06/02 15:29:01:   Calculating solar irradiance...
    2025/06/02 15:29:01:   Reading metadata for SWIR detector...
    2025/06/02 15:29:02:   Calculating solar irradiance...
    2025/06/02 15:29:02:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:02:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:02:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:02:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpcp367g3s/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:02:   L1B product successfully written!
    2025/06/02 15:29:02:   Reading Input Data
    2025/06/02 15:29:02:   Reading metadata for VNIR detector...
    2025/06/02 15:29:02:   Calculating solar irradiance...
    2025/06/02 15:29:02:   Reading metadata for SWIR detector...
    2025/06/02 15:29:03:   Calculating solar irradiance...
    2025/06/02 15:29:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:03:   Reading Input Data
    2025/06/02 15:29:03:   Reading metadata for VNIR detector...
    2025/06/02 15:29:03:   Calculating solar irradiance...
    2025/06/02 15:29:03:   Reading metadata for SWIR detector...
    2025/06/02 15:29:03:   Calculating solar irradiance...
    2025/06/02 15:29:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:04:   Reading metadata for VNIR detector...
    2025/06/02 15:29:04:   Calculating solar irradiance...
    2025/06/02 15:29:04:   Reading metadata for SWIR detector...
    2025/06/02 15:29:04:   Calculating solar irradiance...
    2025/06/02 15:29:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:04:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:04:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:04:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:05:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:05:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp86h521pt/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:06:   L1B product successfully written!
    2025/06/02 15:29:06:   Reading Input Data
    2025/06/02 15:29:06:   Reading metadata for VNIR detector...
    2025/06/02 15:29:06:   Calculating solar irradiance...
    2025/06/02 15:29:06:   Reading metadata for SWIR detector...
    2025/06/02 15:29:06:   Calculating solar irradiance...
    2025/06/02 15:29:06:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:06:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:07:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:28:53:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 15:28:53:   Set to the image number of line
    2025/06/02 15:28:53:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:53:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 15:28:53:   Set to the image number of line
    2025/06/02 15:28:53:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:53:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:28:56:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 15:28:56:   Set to the image number of line
    2025/06/02 15:28:56:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:28:56:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:28:56:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:28:56:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:28:56:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:28:56:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 15:28:56:   Set to the image number of line
    2025/06/02 15:28:57:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:28:57:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:28:57:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:28:57:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:28:57:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:02:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:02:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:02:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:02:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:02:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:02:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:04:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:04:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:05:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:05:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:05:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:05:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:05:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:15.185197

Started | 2025-06-02 15:29:07
Ended | 2025-06-02 15:29:22
Duration | 0:00:15.185197
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:29:08:   Reading Input Data
    2025/06/02 15:29:08:   Reading metadata for VNIR detector...
    2025/06/02 15:29:08:   Calculating solar irradiance...
    2025/06/02 15:29:08:   Reading metadata for SWIR detector...
    2025/06/02 15:29:08:   Calculating solar irradiance...
    2025/06/02 15:29:08:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:09:   Reading metadata for VNIR detector...
    2025/06/02 15:29:09:   Calculating solar irradiance...
    2025/06/02 15:29:09:   Reading metadata for SWIR detector...
    2025/06/02 15:29:09:   Calculating solar irradiance...
    2025/06/02 15:29:09:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:09:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:09:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:09:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:09:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:09:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkvlqmw60/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:10:   L1B product successfully written!
    2025/06/02 15:29:10:   Reading Input Data
    2025/06/02 15:29:10:   Reading metadata for VNIR detector...
    2025/06/02 15:29:10:   Calculating solar irradiance...
    2025/06/02 15:29:10:   Reading metadata for SWIR detector...
    2025/06/02 15:29:10:   Calculating solar irradiance...
    2025/06/02 15:29:10:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:10:   Reading Input Data
    2025/06/02 15:29:10:   Reading metadata for VNIR detector...
    2025/06/02 15:29:11:   Calculating solar irradiance...
    2025/06/02 15:29:11:   Reading metadata for SWIR detector...
    2025/06/02 15:29:11:   Calculating solar irradiance...
    2025/06/02 15:29:11:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:11:   Reading metadata for VNIR detector...
    2025/06/02 15:29:11:   Calculating solar irradiance...
    2025/06/02 15:29:11:   Reading metadata for SWIR detector...
    2025/06/02 15:29:12:   Calculating solar irradiance...
    2025/06/02 15:29:12:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:12:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:12:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:12:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:12:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:12:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:13:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpvz42fr0e/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:14:   L1B product successfully written!
    2025/06/02 15:29:14:   Reading Input Data
    2025/06/02 15:29:14:   Reading metadata for VNIR detector...
    2025/06/02 15:29:14:   Calculating solar irradiance...
    2025/06/02 15:29:14:   Reading metadata for SWIR detector...
    2025/06/02 15:29:14:   Calculating solar irradiance...
    2025/06/02 15:29:14:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:14:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:15:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:16:   Reading Input Data
    2025/06/02 15:29:16:   Reading metadata for VNIR detector...
    2025/06/02 15:29:16:   Calculating solar irradiance...
    2025/06/02 15:29:16:   Reading metadata for SWIR detector...
    2025/06/02 15:29:16:   Calculating solar irradiance...
    2025/06/02 15:29:16:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:17:   Reading metadata for VNIR detector...
    2025/06/02 15:29:17:   Calculating solar irradiance...
    2025/06/02 15:29:17:   Reading metadata for SWIR detector...
    2025/06/02 15:29:17:   Calculating solar irradiance...
    2025/06/02 15:29:17:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:17:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:17:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkme8ftv/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:18:   L1B product successfully written!
    2025/06/02 15:29:18:   Reading Input Data
    2025/06/02 15:29:18:   Reading metadata for VNIR detector...
    2025/06/02 15:29:18:   Calculating solar irradiance...
    2025/06/02 15:29:18:   Reading metadata for SWIR detector...
    2025/06/02 15:29:18:   Calculating solar irradiance...
    2025/06/02 15:29:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:18:   Reading Input Data
    2025/06/02 15:29:18:   Reading metadata for VNIR detector...
    2025/06/02 15:29:18:   Calculating solar irradiance...
    2025/06/02 15:29:18:   Reading metadata for SWIR detector...
    2025/06/02 15:29:19:   Calculating solar irradiance...
    2025/06/02 15:29:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:19:   Reading metadata for VNIR detector...
    2025/06/02 15:29:19:   Calculating solar irradiance...
    2025/06/02 15:29:19:   Reading metadata for SWIR detector...
    2025/06/02 15:29:19:   Calculating solar irradiance...
    2025/06/02 15:29:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:20:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:20:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:20:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:20:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:20:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0ct668lh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:21:   L1B product successfully written!
    2025/06/02 15:29:21:   Reading Input Data
    2025/06/02 15:29:21:   Reading metadata for VNIR detector...
    2025/06/02 15:29:21:   Calculating solar irradiance...
    2025/06/02 15:29:21:   Reading metadata for SWIR detector...
    2025/06/02 15:29:21:   Calculating solar irradiance...
    2025/06/02 15:29:21:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:21:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:22:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:29:09:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:09:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:09:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:09:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:09:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:10:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:10:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:10:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:10:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:10:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:12:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:12:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:12:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:12:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:12:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:17:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:17:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:17:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:17:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:17:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:17:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:20:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:20:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:21:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:21:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:21:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:21:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:21:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:17.923473

Started | 2025-06-02 15:29:22
Ended | 2025-06-02 15:29:40
Duration | 0:00:17.923473
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:29:23:   Reading Input Data
    2025/06/02 15:29:23:   Reading metadata for VNIR detector...
    2025/06/02 15:29:23:   Calculating solar irradiance...
    2025/06/02 15:29:23:   Reading metadata for SWIR detector...
    2025/06/02 15:29:23:   Calculating solar irradiance...
    2025/06/02 15:29:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:24:   Reading metadata for VNIR detector...
    2025/06/02 15:29:24:   Calculating solar irradiance...
    2025/06/02 15:29:24:   Reading metadata for SWIR detector...
    2025/06/02 15:29:24:   Calculating solar irradiance...
    2025/06/02 15:29:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:25:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:25:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:25:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:25:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:25:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptc19lxlo/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:25:   L1B product successfully written!
    2025/06/02 15:29:25:   Reading Input Data
    2025/06/02 15:29:25:   Reading metadata for VNIR detector...
    2025/06/02 15:29:25:   Calculating solar irradiance...
    2025/06/02 15:29:25:   Reading metadata for SWIR detector...
    2025/06/02 15:29:26:   Calculating solar irradiance...
    2025/06/02 15:29:26:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:26:   Reading Input Data
    2025/06/02 15:29:26:   Reading metadata for VNIR detector...
    2025/06/02 15:29:26:   Calculating solar irradiance...
    2025/06/02 15:29:26:   Reading metadata for SWIR detector...
    2025/06/02 15:29:26:   Calculating solar irradiance...
    2025/06/02 15:29:26:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:27:   Reading metadata for VNIR detector...
    2025/06/02 15:29:27:   Calculating solar irradiance...
    2025/06/02 15:29:27:   Reading metadata for SWIR detector...
    2025/06/02 15:29:27:   Calculating solar irradiance...
    2025/06/02 15:29:27:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:27:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:27:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:27:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:27:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:28:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:29:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:29:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpppjg4yv5/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:30:   L1B product successfully written!
    2025/06/02 15:29:30:   Reading Input Data
    2025/06/02 15:29:30:   Reading metadata for VNIR detector...
    2025/06/02 15:29:30:   Calculating solar irradiance...
    2025/06/02 15:29:30:   Reading metadata for SWIR detector...
    2025/06/02 15:29:31:   Calculating solar irradiance...
    2025/06/02 15:29:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:31:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:33:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:33:   Reading Input Data
    2025/06/02 15:29:33:   Reading metadata for VNIR detector...
    2025/06/02 15:29:34:   Calculating solar irradiance...
    2025/06/02 15:29:34:   Reading metadata for SWIR detector...
    2025/06/02 15:29:34:   Calculating solar irradiance...
    2025/06/02 15:29:34:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:34:   Reading metadata for VNIR detector...
    2025/06/02 15:29:34:   Calculating solar irradiance...
    2025/06/02 15:29:34:   Reading metadata for SWIR detector...
    2025/06/02 15:29:35:   Calculating solar irradiance...
    2025/06/02 15:29:35:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:35:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:35:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpk28xh9ji/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:35:   L1B product successfully written!
    2025/06/02 15:29:35:   Reading Input Data
    2025/06/02 15:29:35:   Reading metadata for VNIR detector...
    2025/06/02 15:29:35:   Calculating solar irradiance...
    2025/06/02 15:29:35:   Reading metadata for SWIR detector...
    2025/06/02 15:29:36:   Calculating solar irradiance...
    2025/06/02 15:29:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:36:   Reading Input Data
    2025/06/02 15:29:36:   Reading metadata for VNIR detector...
    2025/06/02 15:29:36:   Calculating solar irradiance...
    2025/06/02 15:29:36:   Reading metadata for SWIR detector...
    2025/06/02 15:29:36:   Calculating solar irradiance...
    2025/06/02 15:29:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:36:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:37:   Reading metadata for VNIR detector...
    2025/06/02 15:29:37:   Calculating solar irradiance...
    2025/06/02 15:29:37:   Reading metadata for SWIR detector...
    2025/06/02 15:29:37:   Calculating solar irradiance...
    2025/06/02 15:29:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:37:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:37:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:37:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:37:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:37:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:38:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:38:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkm_f4dw9/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:38:   L1B product successfully written!
    2025/06/02 15:29:38:   Reading Input Data
    2025/06/02 15:29:38:   Reading metadata for VNIR detector...
    2025/06/02 15:29:39:   Calculating solar irradiance...
    2025/06/02 15:29:39:   Reading metadata for SWIR detector...
    2025/06/02 15:29:39:   Calculating solar irradiance...
    2025/06/02 15:29:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:39:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:40:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:29:25:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:25:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:27:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:27:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:27:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:27:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:27:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:30:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:30:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:35:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:35:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:35:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:35:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:35:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:35:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:35:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:37:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:37:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:38:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:38:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:38:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:38:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:38:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:16.551435

Started | 2025-06-02 15:29:40
Ended | 2025-06-02 15:29:57
Duration | 0:00:16.551435
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:29:41:   Reading Input Data
    2025/06/02 15:29:41:   Reading metadata for VNIR detector...
    2025/06/02 15:29:41:   Calculating solar irradiance...
    2025/06/02 15:29:41:   Reading metadata for SWIR detector...
    2025/06/02 15:29:41:   Calculating solar irradiance...
    2025/06/02 15:29:41:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:42:   Reading metadata for VNIR detector...
    2025/06/02 15:29:42:   Calculating solar irradiance...
    2025/06/02 15:29:42:   Reading metadata for SWIR detector...
    2025/06/02 15:29:42:   Calculating solar irradiance...
    2025/06/02 15:29:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:42:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:42:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:43:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:43:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:43:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpd5andp5q/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:43:   L1B product successfully written!
    2025/06/02 15:29:43:   Reading Input Data
    2025/06/02 15:29:43:   Reading metadata for VNIR detector...
    2025/06/02 15:29:43:   Calculating solar irradiance...
    2025/06/02 15:29:43:   Reading metadata for SWIR detector...
    2025/06/02 15:29:44:   Calculating solar irradiance...
    2025/06/02 15:29:44:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:44:   Reading Input Data
    2025/06/02 15:29:44:   Reading metadata for VNIR detector...
    2025/06/02 15:29:44:   Calculating solar irradiance...
    2025/06/02 15:29:44:   Reading metadata for SWIR detector...
    2025/06/02 15:29:44:   Calculating solar irradiance...
    2025/06/02 15:29:44:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:45:   Reading metadata for VNIR detector...
    2025/06/02 15:29:45:   Calculating solar irradiance...
    2025/06/02 15:29:45:   Reading metadata for SWIR detector...
    2025/06/02 15:29:45:   Calculating solar irradiance...
    2025/06/02 15:29:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:45:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:45:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:45:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:45:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 15:29:45:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:47:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:47:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0gtov376/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:47:   L1B product successfully written!
    2025/06/02 15:29:47:   Reading Input Data
    2025/06/02 15:29:47:   Reading metadata for VNIR detector...
    2025/06/02 15:29:48:   Calculating solar irradiance...
    2025/06/02 15:29:48:   Reading metadata for SWIR detector...
    2025/06/02 15:29:48:   Calculating solar irradiance...
    2025/06/02 15:29:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:48:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:50:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:50:   Reading Input Data
    2025/06/02 15:29:50:   Reading metadata for VNIR detector...
    2025/06/02 15:29:50:   Calculating solar irradiance...
    2025/06/02 15:29:50:   Reading metadata for SWIR detector...
    2025/06/02 15:29:51:   Calculating solar irradiance...
    2025/06/02 15:29:51:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:51:   Reading metadata for VNIR detector...
    2025/06/02 15:29:51:   Calculating solar irradiance...
    2025/06/02 15:29:51:   Reading metadata for SWIR detector...
    2025/06/02 15:29:51:   Calculating solar irradiance...
    2025/06/02 15:29:51:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:52:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:52:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:52:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpemy9lj2y/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:52:   L1B product successfully written!
    2025/06/02 15:29:52:   Reading Input Data
    2025/06/02 15:29:52:   Reading metadata for VNIR detector...
    2025/06/02 15:29:52:   Calculating solar irradiance...
    2025/06/02 15:29:52:   Reading metadata for SWIR detector...
    2025/06/02 15:29:53:   Calculating solar irradiance...
    2025/06/02 15:29:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:53:   Reading Input Data
    2025/06/02 15:29:53:   Reading metadata for VNIR detector...
    2025/06/02 15:29:53:   Calculating solar irradiance...
    2025/06/02 15:29:53:   Reading metadata for SWIR detector...
    2025/06/02 15:29:53:   Calculating solar irradiance...
    2025/06/02 15:29:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:53:   Reading metadata for VNIR detector...
    2025/06/02 15:29:54:   Calculating solar irradiance...
    2025/06/02 15:29:54:   Reading metadata for SWIR detector...
    2025/06/02 15:29:54:   Calculating solar irradiance...
    2025/06/02 15:29:54:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:54:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:54:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 15:29:54:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:55:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:29:55:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp72so_vzu/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 15:29:55:   L1B product successfully written!
    2025/06/02 15:29:55:   Reading Input Data
    2025/06/02 15:29:55:   Reading metadata for VNIR detector...
    2025/06/02 15:29:55:   Calculating solar irradiance...
    2025/06/02 15:29:55:   Reading metadata for SWIR detector...
    2025/06/02 15:29:56:   Calculating solar irradiance...
    2025/06/02 15:29:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:56:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:29:57:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 15:29:43:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:43:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:45:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 15:29:45:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 15:29:45:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 15:29:45:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 15:29:45:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 15:29:47:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:47:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:47:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:47:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:47:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:52:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:52:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:52:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:52:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:52:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:52:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:52:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 15:29:54:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:54:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 15:29:55:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:55:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:55:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:55:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:55:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.300734

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-06-02 15:29:57
Ended | 2025-06-02 15:29:59
Duration | 0:00:02.300734
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:29:57:   Reading Input Data
    2025/06/02 15:29:58:   Reading metadata for VNIR detector...
    2025/06/02 15:29:58:   Calculating solar irradiance...
    2025/06/02 15:29:58:   Reading metadata for SWIR detector...
    2025/06/02 15:29:58:   Calculating solar irradiance...
    2025/06/02 15:29:58:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:29:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:29:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:29:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpp6_tp1ho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:29:59:   L1B product successfully written!
    2025/06/02 15:29:59:   Reading Input Data
    2025/06/02 15:29:59:   Reading metadata for VNIR detector...
    2025/06/02 15:29:59:   Calculating solar irradiance...
    2025/06/02 15:29:59:   Reading metadata for SWIR detector...
    2025/06/02 15:29:59:   Calculating solar irradiance...
    2025/06/02 15:29:59:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 15:29:58:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:29:58:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:29:58:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:29:58:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:29:58:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.289200

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-06-02 15:29:59
Ended | 2025-06-02 15:30:02
Duration | 0:00:03.289200
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:00:   Reading Input Data
    2025/06/02 15:30:00:   Reading metadata for VNIR detector...
    2025/06/02 15:30:00:   Calculating solar irradiance...
    2025/06/02 15:30:00:   Reading metadata for SWIR detector...
    2025/06/02 15:30:00:   Calculating solar irradiance...
    2025/06/02 15:30:00:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:01:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:30:01:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:30:01:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpstzj11qc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 15:30:02:   L1B product successfully written!
    2025/06/02 15:30:02:   Reading Input Data
    2025/06/02 15:30:02:   Reading metadata for VNIR detector...
    2025/06/02 15:30:02:   Calculating solar irradiance...
    2025/06/02 15:30:02:   Reading metadata for SWIR detector...
    2025/06/02 15:30:02:   Calculating solar irradiance...
    2025/06/02 15:30:02:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 15:30:01:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 15:30:01:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 15:30:01:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 15:30:01:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 15:30:01:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.369506

Started | 2025-06-02 15:30:02
Ended | 2025-06-02 15:30:05
Duration | 0:00:02.369506
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:03:   Reading Input Data
    2025/06/02 15:30:03:   Reading metadata for VNIR detector...
    2025/06/02 15:30:03:   Calculating solar irradiance...
    2025/06/02 15:30:03:   Reading metadata for SWIR detector...
    2025/06/02 15:30:03:   Calculating solar irradiance...
    2025/06/02 15:30:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:04:   Computing VNIR geolayer...
    2025/06/02 15:30:04:   Computing SWIR geolayer...
    2025/06/02 15:30:04:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/06/02 15:30:05:   L1B product successfully written!

##### Captured stderr call

    2025/06/02 15:30:03:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.759398

Started | 2025-06-02 15:30:05
Ended | 2025-06-02 15:30:07
Duration | 0:00:01.759398
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:05:   Reading Input Data
    2025/06/02 15:30:05:   Reading metadata for VNIR detector...
    2025/06/02 15:30:05:   Calculating solar irradiance...
    2025/06/02 15:30:05:   Reading metadata for SWIR detector...
    2025/06/02 15:30:06:   Calculating solar irradiance...
    2025/06/02 15:30:06:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:06:   Computing VNIR geolayer...
    2025/06/02 15:30:06:   Computing SWIR geolayer...

##### Captured stderr call

    2025/06/02 15:30:05:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:25.807572

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.485075

Started | 2025-06-02 15:30:07
Ended | 2025-06-02 15:30:12
Duration | 0:00:05.485075
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:07:   Reading Input Data
    2025/06/02 15:30:07:   Reading metadata for VNIR detector...
    2025/06/02 15:30:07:   Calculating solar irradiance...
    2025/06/02 15:30:07:   Reading metadata for SWIR detector...
    2025/06/02 15:30:07:   Calculating solar irradiance...
    2025/06/02 15:30:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:08:   Starting orthorectification...
    2025/06/02 15:30:08:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/06/02 15:30:08:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:09:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:10:   Merging VNIR and SWIR data...
    2025/06/02 15:30:10:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:30:10:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:30:11:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:05.267628

Started | 2025-06-02 15:30:12
Ended | 2025-06-02 15:30:17
Duration | 0:00:05.267628
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:12:   Reading Input Data
    2025/06/02 15:30:12:   Reading metadata for VNIR detector...
    2025/06/02 15:30:13:   Calculating solar irradiance...
    2025/06/02 15:30:13:   Reading metadata for SWIR detector...
    2025/06/02 15:30:13:   Calculating solar irradiance...
    2025/06/02 15:30:13:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:13:   Starting orthorectification...
    2025/06/02 15:30:13:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/06/02 15:30:13:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:14:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:15:   Merging VNIR and SWIR data...
    2025/06/02 15:30:15:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:30:16:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:30:16:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.968556

Started | 2025-06-02 15:30:17
Ended | 2025-06-02 15:30:24
Duration | 0:00:06.968556
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:17:   Reading Input Data
    2025/06/02 15:30:18:   Reading metadata for VNIR detector...
    2025/06/02 15:30:18:   Calculating solar irradiance...
    2025/06/02 15:30:18:   Reading metadata for SWIR detector...
    2025/06/02 15:30:18:   Calculating solar irradiance...
    2025/06/02 15:30:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:19:   Computing VNIR geolayer...
    2025/06/02 15:30:19:   Computing SWIR geolayer...
    2025/06/02 15:30:19:   Starting orthorectification...
    2025/06/02 15:30:19:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/06/02 15:30:19:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:20:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:21:   Merging VNIR and SWIR data...
    2025/06/02 15:30:21:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:30:22:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:30:22:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:30:22:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:30:22:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:30:23:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:30:23:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:30:23:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 15:30:17:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:08.061148

Started | 2025-06-02 15:30:24
Ended | 2025-06-02 15:30:32
Duration | 0:00:08.061148
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:24:   Reading Input Data
    2025/06/02 15:30:25:   Reading metadata for VNIR detector...
    2025/06/02 15:30:25:   Calculating solar irradiance...
    2025/06/02 15:30:25:   Reading metadata for SWIR detector...
    2025/06/02 15:30:25:   Calculating solar irradiance...
    2025/06/02 15:30:25:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:26:   Computing VNIR geolayer...
    2025/06/02 15:30:26:   Computing SWIR geolayer...
    2025/06/02 15:30:26:   Starting orthorectification...
    2025/06/02 15:30:26:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 15:30:26:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:27:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 15:30:28:   Merging VNIR and SWIR data...
    2025/06/02 15:30:28:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 15:30:29:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 15:30:29:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 15:30:29:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 15:30:30:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 15:30:30:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 15:30:30:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 15:30:31:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 15:30:24:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.004681

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.004681
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.004780

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.004780
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.003787

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.003787
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.003192

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.003192
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.003034

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.003034
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.005692

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:32
Duration | 0:00:00.005692
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.559055

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.559055

Started | 2025-06-02 15:30:32
Ended | 2025-06-02 15:30:37
Duration | 0:00:04.559055
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmpx__u9oo8
    2025/06/02 15:30:33:   Reading Input Data
    2025/06/02 15:30:33:   Reading metadata for VNIR detector...
    2025/06/02 15:30:33:   Calculating solar irradiance...
    2025/06/02 15:30:33:   Reading metadata for SWIR detector...
    2025/06/02 15:30:33:   Calculating solar irradiance...
    2025/06/02 15:30:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:34:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:30:34:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:30:35:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 15:30:35:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmpxb386rqw
    2025/06/02 15:30:35:   Reading Input Data
    2025/06/02 15:30:35:   Reading metadata for VNIR detector...
    2025/06/02 15:30:35:   Calculating solar irradiance...
    2025/06/02 15:30:35:   Reading metadata for SWIR detector...
    2025/06/02 15:30:36:   Calculating solar irradiance...
    2025/06/02 15:30:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:36:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:36:   Computing SNR from VNIR TOA radiance.
    2025/06/02 15:30:37:   Computing SNR from SWIR TOA radiance.
    2025/06/02 15:30:37:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 15:30:37:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:16.219979

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:16.219979

Started | 2025-06-02 15:30:37
Ended | 2025-06-02 15:30:53
Duration | 0:00:16.219979
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:37:   Reading Input Data
    2025/06/02 15:30:37:   Reading metadata for VNIR detector...
    2025/06/02 15:30:38:   Calculating solar irradiance...
    2025/06/02 15:30:38:   Reading metadata for SWIR detector...
    2025/06/02 15:30:38:   Calculating solar irradiance...
    2025/06/02 15:30:38:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:38:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:39:   Computing VNIR geolayer...
    2025/06/02 15:30:39:   Computing SWIR geolayer...
    2025/06/02 15:30:39:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 15:30:39:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 15:30:40:   Preparing reference image for co-registration.
    2025/06/02 15:30:40:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 15:30:52:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.17s
    2025/06/02 15:30:53:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 15:30:53:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/06/02 15:30:37:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 15:30:39:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.6% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.4% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.5% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.2% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.1% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.3% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.6% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.5% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.2% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.3% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.3% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.2% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.4% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.4% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.4% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.4% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.2% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.5% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.4% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.5% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.9% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.1% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.5% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.5% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.5% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.3% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.3% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.9% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.4% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.6% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.6% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.7% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.3% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.3% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.6% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.4% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.9% Complete  => 0:00:00
    Warping progress     |============================================------| 87.2% Complete  => 0:00:00
    Warping progress     |============================================------| 88.5% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.3% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.4% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.3% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:11
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:11
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:11
    	progress: |==================================----------------| 68.3% Complete  => 0:00:11
    	progress: |==================================----------------| 68.9% Complete  => 0:00:11
    	progress: |===================================---------------| 69.6% Complete  => 0:00:11
    	progress: |===================================---------------| 70.2% Complete  => 0:00:11
    	progress: |===================================---------------| 70.8% Complete  => 0:00:11
    	progress: |====================================--------------| 71.4% Complete  => 0:00:11
    	progress: |====================================--------------| 72.0% Complete  => 0:00:11
    	progress: |====================================--------------| 72.7% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:11
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:11
    	progress: |======================================------------| 75.2% Complete  => 0:00:11
    	progress: |======================================------------| 75.8% Complete  => 0:00:11
    	progress: |======================================------------| 76.4% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:11
    	progress: |========================================----------| 79.5% Complete  => 0:00:11
    	progress: |========================================----------| 80.1% Complete  => 0:00:11
    	progress: |========================================----------| 80.7% Complete  => 0:00:11
    	progress: |=========================================---------| 81.4% Complete  => 0:00:11
    	progress: |=========================================---------| 82.0% Complete  => 0:00:11
    	progress: |=========================================---------| 82.6% Complete  => 0:00:11
    	progress: |==========================================--------| 83.2% Complete  => 0:00:11
    	progress: |==========================================--------| 83.9% Complete  => 0:00:11
    	progress: |==========================================--------| 84.5% Complete  => 0:00:11
    	progress: |===========================================-------| 85.1% Complete  => 0:00:11
    	progress: |===========================================-------| 85.7% Complete  => 0:00:11
    	progress: |===========================================-------| 86.3% Complete  => 0:00:11
    	progress: |===========================================-------| 87.0% Complete  => 0:00:11
    	progress: |============================================------| 87.6% Complete  => 0:00:11
    	progress: |============================================------| 88.2% Complete  => 0:00:11
    	progress: |============================================------| 88.8% Complete  => 0:00:11
    	progress: |=============================================-----| 89.4% Complete  => 0:00:11
    	progress: |=============================================-----| 90.1% Complete  => 0:00:11
    	progress: |=============================================-----| 90.7% Complete  => 0:00:11
    	progress: |==============================================----| 91.3% Complete  => 0:00:11
    	progress: |==============================================----| 91.9% Complete  => 0:00:11
    	progress: |==============================================----| 92.5% Complete  => 0:00:11
    	progress: |===============================================---| 93.2% Complete  => 0:00:11
    	progress: |===============================================---| 93.8% Complete  => 0:00:11
    	progress: |===============================================---| 94.4% Complete  => 0:00:11
    	progress: |================================================--| 95.0% Complete  => 0:00:11
    	progress: |================================================--| 95.7% Complete  => 0:00:11
    	progress: |================================================--| 96.3% Complete  => 0:00:11
    	progress: |================================================--| 96.9% Complete  => 0:00:11
    	progress: |=================================================-| 97.5% Complete  => 0:00:11
    	progress: |=================================================-| 98.1% Complete  => 0:00:11
    	progress: |=================================================-| 98.8% Complete  => 0:00:11
    	progress: |==================================================| 99.4% Complete  => 0:00:11
    	progress: |==================================================| 100.0% Complete  => 0:00:11

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:34.401103

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.683323

Started | 2025-06-02 15:30:53
Ended | 2025-06-02 15:30:55
Duration | 0:00:01.683323
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:53:   Reading Input Data
    2025/06/02 15:30:54:   Reading metadata for VNIR detector...
    2025/06/02 15:30:54:   Calculating solar irradiance...
    2025/06/02 15:30:54:   Reading metadata for SWIR detector...
    2025/06/02 15:30:54:   Calculating solar irradiance...
    2025/06/02 15:30:54:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.289942

Started | 2025-06-02 15:30:55
Ended | 2025-06-02 15:30:56
Duration | 0:00:01.289942
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 15:30:55:   Reading Input Data
    2025/06/02 15:30:55:   Reading metadata for VNIR detector...
    2025/06/02 15:30:55:   Calculating solar irradiance...
    2025/06/02 15:30:55:   Reading metadata for SWIR detector...
    2025/06/02 15:30:56:   Calculating solar irradiance...
    2025/06/02 15:30:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.378467

Started | 2025-06-02 15:30:56
Ended | 2025-06-02 15:30:58
Duration | 0:00:02.378467
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 15:30:56:   Reading Input Data
    2025/06/02 15:30:56:   Reading metadata for VNIR detector...
    2025/06/02 15:30:57:   Calculating solar irradiance...
    2025/06/02 15:30:57:   Reading metadata for SWIR detector...
    2025/06/02 15:30:57:   Calculating solar irradiance...
    2025/06/02 15:30:57:   Reading image masks in VNIR sensor geometry.
    2025/06/02 15:30:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 15:30:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 15:30:58:   Computing VNIR geolayer...
    2025/06/02 15:30:58:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 15:30:56:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.389107

Started | 2025-06-02 15:30:58
Ended | 2025-06-02 15:30:59
Duration | 0:00:00.389107
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.383844

Started | 2025-06-02 15:30:59
Ended | 2025-06-02 15:30:59
Duration | 0:00:00.383844
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.359209

Started | 2025-06-02 15:30:59
Ended | 2025-06-02 15:31:00
Duration | 0:00:00.359209
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:20.740394

Started | 2025-06-02 15:31:00
Ended | 2025-06-02 15:31:20
Duration | 0:00:20.740394
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.409560

Started | 2025-06-02 15:31:20
Ended | 2025-06-02 15:31:21
Duration | 0:00:00.409560
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.369568

Started | 2025-06-02 15:31:21
Ended | 2025-06-02 15:31:21
Duration | 0:00:00.369568
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.004297

Started | 2025-06-02 15:31:21
Ended | 2025-06-02 15:31:21
Duration | 0:00:00.004297
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002768

Started | 2025-06-02 15:31:21
Ended | 2025-06-02 15:31:21
Duration | 0:00:00.002768
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.002993

Started | 2025-06-02 15:31:21
Ended | 2025-06-02 15:31:21
Duration | 0:00:00.002993
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:01.979947

Started | 2025-06-02 15:31:21
Ended | 2025-06-02 15:31:23
Duration | 0:00:01.979947
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.512972

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-06-02 15:31:23
Ended | 2025-06-02 15:31:24
Duration | 0:00:00.512972
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.014801

Started | 2025-06-02 15:31:24
Ended | 2025-06-02 15:31:26
Duration | 0:00:02.014801
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.437136

Started | 2025-06-02 15:31:26
Ended | 2025-06-02 15:31:27
Duration | 0:00:01.437136
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.442776

Started | 2025-06-02 15:31:27
Ended | 2025-06-02 15:31:28
Duration | 0:00:00.442776
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.005773

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.005773

Started | 2025-06-02 15:31:28
Ended | 2025-06-02 15:31:28
Duration | 0:00:00.005773
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown